From: Marco Costalba Date: Mon, 31 Dec 2007 23:47:47 GMT Subject: Re: [PATCH WIP] sha1-lookup: make selection of 'middle' less aggressive Message-ID: In-Reply-To: On Dec 31, 2007 9:37 PM, Linus Torvalds wrote: > > > Even today, I don't really know of a better compression choice, despite > now being more aware of how critical uncompression performance is. > In the kernel, from not long ago, is used also LZO compression that _seems_ much faster to decompress then zlib http://lkml.org/lkml/2007/5/1/297 The developer, Richard Purdie, says it's also 40% faster to read for jffs2. > > Quite possibly, the cache miss costs dominate over any algorithmic costs. > What way could be used to build up a test to check this? Thanks Marco